var _extends = Object.assign || function (target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i]; for (var key in source) { if (Object.prototype.hasOwnProperty.call(source, key)) { target[key] = source[key]; } } } return target; };

import { h } from 'preact';
import ComponentCode from './component-code';
import getPropVariants from '../utils/get-prop-variants';
import omit from '../utils/omit';

const serializeProps = props => {
  if (!props) {
    return '';
  }
  return Object.keys(props).reduce((buffer, prop) => {
    const value = props[prop];
    return `${buffer} ${prop}${value === true ? '' : `="${value}"`}`;
  }, '');
};

const componentString = (name, props, content) => `<${name}${serializeProps(props)}${content ? `>${content}</${name}` : ` />`}`;

export default (({ Component, children, name }) => {
  const { options = {} } = Component.definition;
  const variants = getPropVariants(options);

  const code = variants.reduce((buff, props) => buff + componentString(name, props, children) + '\n', '');

  return h(
    ComponentCode,
    { name: name, code: code },
    variants.map(props => h(Component, _extends({
      title: componentString(name, props, children)
    }, Object.assign({}, props, { children }), {
      className: 'mr2 mb2'
    })))
  );
});