import { h } from 'preact';
import { Link, SupportLink, Button, LogoDark, LogoLight, Input, Select, Textarea, TooltipButton, Icon, MessagePageCrate } from '../';
import Section from './section';
import ComponentCode from './component-code';
import Introspect from './introspect';

export const ButtonSection = () => h(
  Section,
  { title: 'Buttons' },
  h(Introspect, { Component: Button, name: 'Button', children: 'Button' })
);

export const LinkSection = () => h(
  Section,
  { title: 'Links' },
  h(
    ComponentCode,
    { name: 'Link', code: `<Link href='something'>hi</Link>` },
    h(
      Link,
      { href: 'something' },
      'Some text'
    )
  ),
  h(
    ComponentCode,
    { name: 'SupportLink', code: `<SupportLink />` },
    h(SupportLink, null)
  )
);

export const LogoSection = () => h(
  Section,
  { title: 'Logos' },
  h(
    ComponentCode,
    { name: 'LogoLight', code: `<LogoLight className="w5" />` },
    h(LogoLight, { className: 'w5' })
  ),
  h(
    ComponentCode,
    {
      name: 'LogoDark',
      code: `<div className="bg-dark-blue pa3 w5">
  <LogoDark />
</div>`
    },
    h(
      'div',
      { className: 'bg-dark-blue pa3 w5' },
      h(LogoDark, null)
    )
  )
);

export const InputSection = () => h(
  Section,
  { title: 'Inputs' },
  h(
    ComponentCode,
    { name: 'Input', code: `<Input />` },
    h(Input, null)
  ),
  h(
    ComponentCode,
    {
      name: 'Select',
      code: `<Select>
  <option>option 1</option>
  <option>option 2</option>
</Select>`
    },
    h(
      Select,
      null,
      h(
        'option',
        null,
        'option 1'
      ),
      h(
        'option',
        null,
        'option 2'
      )
    )
  ),
  h(
    ComponentCode,
    { name: 'Textarea', code: `<Textarea />` },
    h(Textarea, null)
  ),
  h(
    ComponentCode,
    { name: 'TooltipButton', code: `<TooltipButton />` },
    h(
      TooltipButton,
      { text: 'some content' },
      'Stuff goes here'
    )
  )
);

export const IconSection = () => h(
  Section,
  { title: 'Icons' },
  h(
    ComponentCode,
    {
      name: 'Icon',
      code: `<Icon icon="pill" />
<Icon icon="close" />`
    },
    h(Icon, { icon: 'pill' }),
    h(Icon, { icon: 'close' })
  )
);

export const MessagePageCrateSection = () => h(
  Section,
  { title: 'Message Page Crate' },
  h(
    ComponentCode,
    {
      name: 'MessagePageCrate',
      code: `<MessagePageCrate loading>Loading</MessagePageCrate>
<MessagePageCrate warning>Uh oh!</MessagePageCrate>
<MessagePageCrate error>Aw Crap!</MessagePageCrate>`
    },
    h(
      MessagePageCrate,
      null,
      'Hello there!'
    ),
    h(
      MessagePageCrate,
      { loading: true },
      'Loading'
    ),
    h(
      MessagePageCrate,
      { warning: true },
      'Uh oh!'
    ),
    h(
      MessagePageCrate,
      { error: true },
      'Aw Crap!'
    )
  )
);

export { default as DialogSection } from './dialog-section';
export { default as NumpadSection } from './numpad-section';