export const writeCookie = (item, value, { maxAge, expires, secure = false, domain } = {}) => {
  const cookieData = {
    [item]: value,
    domain: domain || location.hostname,
    path: '/',
    secure
  };

  if (location.hostname === 'localhost') {
    cookieData.secure = false;
  }

  if (maxAge) {
    cookieData['max-age'] = Math.floor(maxAge / 1000); // convert to seconds
  } else if (expires) {
    cookieData.expires = expires.toGMTString();
  }

  const cookieString = Object.keys(cookieData).reduce((result, key) => {
    const value = cookieData[key];
    if (typeof value === 'boolean') {
      if (value === true) {
        result.push(key);
      }
    } else {
      result.push(`${key}=${value}`);
    }
    return result;
  }, []).join(';');

  document.cookie = cookieString;
};

export const readCookie = name => {
  const found = document.cookie.split(';').find(item => item.startsWith(name));
  return found ? found.split('=')[1] : null;
};

export const deleteCookie = (item, domain) => writeCookie(item, '', { expires: new Date(0), domain });