import { h } from 'preact';
import cn from 'classnames';
import omit from './omit';

const alwaysPassThroughProps = ['disabled'];

export default (args => {
  const {
    tagName = 'div',
    baseClasses = '',
    options = {},
    style,
    fn,
    passThroughProps = [],
    defaultProps,
    renderChildren
  } = args;

  const defaults = Object.assign({}, defaultProps);
  const propsToRemove = ['className', 'tagName'];

  const allOptionValues = Object.keys(options).reduce((result, key) => {
    const value = options[key];
    if (typeof value !== 'object') {
      defaults[key] = value;
      propsToRemove.push(key);
      result.push(value);
    } else {
      result.push(...value);
    }
    return result;
  }, []);

  propsToRemove.push(...allOptionValues.filter(key => !passThroughProps.includes(key) && !alwaysPassThroughProps.includes(key)));

  const componentFn = incomingProps => {
    const props = Object.assign({}, defaults, incomingProps);
    const finalTagName = props.tagName || tagName;
    const passThroughProps = omit(props, propsToRemove);
    const className = cn(baseClasses, fn && fn(props), props.className);
    const combinedStyle = Object.assign({}, style, props.style);
    const renderedChildren = renderChildren ? renderChildren(props) : props.children;

    return h(finalTagName, Object.assign({ className, style: combinedStyle }, passThroughProps), ...renderedChildren);
  };

  componentFn.definition = args;

  return componentFn;
});